pub trait ReadBufExt {
// Required method
fn with_limited<F, T>(&mut self, limit: usize, callback: F) -> T
where F: FnOnce(&mut ReadBuf<'_>) -> T;
}Available on crate feature
tokio1 only.Expand description
Extensions to tokio’s ReadBuf.
Requires the tokio1 feature to be enabled.
Required Methods
Sourcefn with_limited<F, T>(&mut self, limit: usize, callback: F) -> T
fn with_limited<F, T>(&mut self, limit: usize, callback: F) -> T
Convert this ReadBuf into a limited one backed by the same storage, then
call the callback with this limited instance..
Any changes to the ReadBuf made by the callback are reflected in the original
ReadBuf.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl<'a> ReadBufExt for ReadBuf<'a>
Available on crate feature futures03 only.
impl<'a> ReadBufExt for ReadBuf<'a>
Available on crate feature
futures03 only.